@@ -17,7 +17,7 @@ def 多进程_启动进程(目标函数, 元组参数):
         进程对象 = 进程_启动进程(目标函数, (队列对象,"123",456))
 
     小提示：
-    程序必须要在保护块下进行启动，否则会出现无限递归问题导致异常,元组成员数有多少个，目标函数接收的参数就应该有多少个
+    程序必需要在保护块下进行启动，否则会出现无限递归问题导致异常,元组成员数有多少个，目标函数接收的参数就应该有多少个
     """
     try:
         # 创建一个进程
@@ -28,4 +28,4 @@ def 多进程_启动进程(目标函数, 元组参数):
 
         return p
     except Exception:
-        return None
\ No newline at end of file
+        return None
